@@ -3,6 +3,7 @@
 Integration (not unit) tests for pylast.py
 """
 import os
+import sys
 import time
 import unittest
 
@@ -12,6 +13,9 @@ from flaky import flaky
 import pylast
 
 
+PY37 = sys.version_info[:2] == (3, 7)
+
+
 def load_secrets():
     secrets_file = "test_pylast.yaml"
     if os.path.isfile(secrets_file):
